You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@whimsical.apache.org by ru...@apache.org on 2017/12/05 01:46:49 UTC

[whimsy] branch master updated: apply improvement suggested by Sebb

This is an automated email from the ASF dual-hosted git repository.

rubys pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git


The following commit(s) were added to refs/heads/master by this push:
     new 26849c6  apply improvement suggested by Sebb
26849c6 is described below

commit 26849c6f1fabf249e0709eaa555185709f100183
Author: Sam Ruby <ru...@intertwingly.net>
AuthorDate: Mon Dec 4 20:46:32 2017 -0500

    apply improvement suggested by Sebb
---
 lib/whimsy/asf/agenda/special.rb            | 2 +-
 www/board/agenda/views/actions/post.json.rb | 4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/whimsy/asf/agenda/special.rb b/lib/whimsy/asf/agenda/special.rb
index ce536de..068cbbe 100644
--- a/lib/whimsy/asf/agenda/special.rb
+++ b/lib/whimsy/asf/agenda/special.rb
@@ -68,7 +68,7 @@ class ASF::Board::Agenda
       next if @quick
 
       asfid = '[a-z][-.a-z0-9_]+' # dot added to help detect errors
-      list_item = '^[[:space:]]*(?:[-*\u2022]\s*)?(.*?)[[:space:]]+'
+      list_item = '^[[:blank:]]*(?:[-*\u2022]\s*)?(.*?)[[:blank:]]+'
 
       people = text.scan(/#{list_item}\((#{asfid})\)\s*$/)
       people += text.scan(/#{list_item}\((#{asfid})(?:@|\s*at\s*)
diff --git a/www/board/agenda/views/actions/post.json.rb b/www/board/agenda/views/actions/post.json.rb
index c7a3a46..c6b3534 100644
--- a/www/board/agenda/views/actions/post.json.rb
+++ b/www/board/agenda/views/actions/post.json.rb
@@ -15,8 +15,8 @@ Agenda.update(@agenda, @message) do |agenda|
   # remove trailing whitespace
   @report.sub! /\s*\Z/, ''
 
-  # convert unicode space characters (excluding CRLF) to an ASCII space
-  @report.gsub!(/[[:space:]]/) {|c| "\r\n".include?(c) ? c : ' '}
+  # convert unicode blank characters to an ASCII space
+  @report.gsub!(/[[:blank:]]/, ' ')
 
   if @attach == '7?'
     # new special order

-- 
To stop receiving notification emails like this one, please contact
['"commits@whimsical.apache.org" <co...@whimsical.apache.org>'].